freckle-http-0.0.0.0: Toolkit for making HTTP requests
Safe HaskellNone
LanguageGHC2021

Freckle.App.Http.Cache.Gzip

Description

Type and functions for handling gzipped HTTP responses

In order to optimize caching of responses in storage with size limitations, we cache gzipped responses as-is. This requires disabling the automatic decompression of http-client and handling it ourselves.

The module makes that a type-enforced process:

Synopsis

Documentation

requestPotentiallyGzipped :: Functor m => (Request -> m (Response body)) -> Request -> m (Response (PotentiallyGzipped body)) Source #

Run a request without automatic decompress and tag the body type